/**
 * @file configvar.c
 * This is the main configvar program start point.
 *
 * @details This program demonstrates config variable field patching.
 * It relies on the variables.cfg board type for program loading.
 *
 * Many variables are defined in variables.cfg
 * Integer variable fields are the only ones that can be patched.
 * Fields with strings will be ignored.
 *
 * Please see the attached variable.cfg file for more field info.
 */
#include <stdio.h>
#include <propeller.h>

/*
 * OUTPUT
 *
PropellerGCC Config Variable Field Demo

_cfg_clkfreq        	80000000	0x04C4B400
_cfg_clkmode        	111	0x0000006F
_cfg_baudrate       	115200	0x0001C200
_cfg_rxpin          	31	0x0000001F
_cfg_txpin          	30	0x0000001E
_cfg_cache_driver   	-1	0xFFFFFFFF
_cfg_cache_size     	8192	0x00002000
_cfg_cache_param1   	0	0x00000000
_cfg_cache_param2   	0	0x00000000
_cfg_sd_driver      	-1	0xFFFFFFFF
_cfg_sdspi_do       	0	0x00000000
_cfg_sdspi_clk      	1	0x00000001
_cfg_sdspi_di       	2	0x00000002
_cfg_sdspi_cs       	3	0x00000003
_cfg_sdspi_clr      	-1	0xFFFFFFFF
_cfg_sdspi_inc      	-1	0xFFFFFFFF
_cfg_sdspi_addr     	-1	0xFFFFFFFF
_cfg_sdspi_select   	-1	0xFFFFFFFF
_cfg_sdspi_mask     	-1	0xFFFFFFFF
_cfg_tvpin          	12	0x0000000C
_cfg_vgapin         	16	0x00000010
_cfg_kbclk_pin      	27	0x0000001B
_cfg_kbdat_pin      	26	0x0000001A
_cfg_mouseclk_pin   	25	0x00000019
_cfg_mousedat_pin   	24	0x00000018
_cfg_scl_pin        	28	0x0000001C
_cfg_sda_pin        	29	0x0000001D
*/

int _cfg_clkfreq = -1; // 80000000
int _cfg_clkmode = -1; // XTAL1+PLL16X
int _cfg_baudrate = -1; // 115200
int _cfg_rxpin = -1; // 31
int _cfg_txpin = -1; // 30
int _cfg_cache_driver = -1; // eeprom_cache.dat
int _cfg_cache_size = -1; // 8K
int _cfg_cache_param1 = -1; // 0
int _cfg_cache_param2 = -1; // 0
int _cfg_sd_driver = -1; // sd_driver.dat
int _cfg_sdspi_do = -1; // 0
int _cfg_sdspi_clk = -1; // 1
int _cfg_sdspi_di = -1; // 2
int _cfg_sdspi_cs = -1; // 3
int _cfg_sdspi_clr = -1; // 
int _cfg_sdspi_inc = -1; // 
int _cfg_sdspi_addr = -1; // 
int _cfg_sdspi_select = -1; // ?
int _cfg_sdspi_mask = -1; // ?
int _cfg_tvpin = -1; // 12
int _cfg_vgapin = -1; // 16
int _cfg_kbclk_pin = -1; // 27
int _cfg_kbdat_pin = -1; // 26
int _cfg_mouseclk_pin = -1; // 25
int _cfg_mousedat_pin = -1; // 24
int _cfg_scl_pin = -1; // 28
int _cfg_sda_pin = -1; //29

/**
 * Main program function.
 */
int main(void)
{
    waitcnt(CLKFREQ+CNT);
    setbuf(stdout,0);

    printf("PropellerGCC Config Variable Field Demo\n\n");

    printf("_cfg_clkfreq        %8d\t0x%08x\n", _cfg_clkfreq, _cfg_clkfreq);
    printf("_cfg_clkmode        %8d\t0x%08x\n", _cfg_clkmode, _cfg_clkmode);
    printf("_cfg_baudrate       %8d\t0x%08x\n", _cfg_baudrate, _cfg_baudrate);
    printf("_cfg_rxpin          %8d\t0x%08x\n", _cfg_rxpin, _cfg_rxpin);
    printf("_cfg_txpin          %8d\t0x%08x\n", _cfg_txpin, _cfg_txpin);
    printf("_cfg_cache_driver   %8d\t0x%08x\n", _cfg_cache_driver, _cfg_cache_driver);
    printf("_cfg_cache_size     %8d\t0x%08x\n", _cfg_cache_size, _cfg_cache_size);
    printf("_cfg_cache_param1   %8d\t0x%08x\n", _cfg_cache_param1, _cfg_cache_param1);
    printf("_cfg_cache_param2   %8d\t0x%08x\n", _cfg_cache_param2, _cfg_cache_param2);
    printf("_cfg_sd_driver      %8d\t0x%08x\n", _cfg_sd_driver, _cfg_sd_driver);
    printf("_cfg_sdspi_do       %8d\t0x%08x\n", _cfg_sdspi_do, _cfg_sdspi_do);
    printf("_cfg_sdspi_clk      %8d\t0x%08x\n", _cfg_sdspi_clk, _cfg_sdspi_clk);
    printf("_cfg_sdspi_di       %8d\t0x%08x\n", _cfg_sdspi_di, _cfg_sdspi_di);
    printf("_cfg_sdspi_cs       %8d\t0x%08x\n", _cfg_sdspi_cs, _cfg_sdspi_cs);
    printf("_cfg_sdspi_clr      %8d\t0x%08x\n", _cfg_sdspi_clr, _cfg_sdspi_clr);
    printf("_cfg_sdspi_inc      %8d\t0x%08x\n", _cfg_sdspi_inc, _cfg_sdspi_inc);
    printf("_cfg_sdspi_addr     %8d\t0x%08x\n", _cfg_sdspi_addr, _cfg_sdspi_addr);
    printf("_cfg_sdspi_select   %8d\t0x%08x\n", _cfg_sdspi_select, _cfg_sdspi_select);
    printf("_cfg_sdspi_mask     %8d\t0x%08x\n", _cfg_sdspi_mask, _cfg_sdspi_mask);
    printf("_cfg_tvpin          %8d\t0x%08x\n", _cfg_tvpin, _cfg_tvpin);
    printf("_cfg_vgapin         %8d\t0x%08x\n", _cfg_vgapin, _cfg_vgapin);
    printf("_cfg_kbclk_pin      %8d\t0x%08x\n", _cfg_kbclk_pin, _cfg_kbclk_pin);
    printf("_cfg_kbdat_pin      %8d\t0x%08x\n", _cfg_kbdat_pin, _cfg_kbdat_pin);
    printf("_cfg_mouseclk_pin   %8d\t0x%08x\n", _cfg_mouseclk_pin, _cfg_mouseclk_pin);
    printf("_cfg_mousedat_pin   %8d\t0x%08x\n", _cfg_mousedat_pin, _cfg_mousedat_pin);
    printf("_cfg_scl_pin        %8d\t0x%08x\n", _cfg_scl_pin, _cfg_scl_pin);
    printf("_cfg_sda_pin        %8d\t0x%08x\n", _cfg_sda_pin, _cfg_sda_pin);

    return 0;
}

